@@ -23,8 +23,8 @@ class UvaSensor(I2cDevice):
         :return: UVa reading in W m^-2
         """
         # scale from sensor is 5 uW / cm^2  / encoder count.
-        msb = self.bus.read_byte_data(0x39, 0x00)
-        lsb = self.bus.read_byte_data(0x38, 0x00)
+        msb = self.bus.read_byte(0x39)
+        lsb = self.bus.read_byte(0x38)
         result = UvaMeasurement(((msb << 8) | lsb) * 5e-2)
         packet = {
             "uva": str(result.uva)
